EBrake

Struct EBrake 

pub struct EBrake { /* private fields */ }
The emergency brake is a circular queue of boolean samples with a defined size and tolerance.

Implementations

Source

impl EBrake

pub fn new(samples: usize, tolerance: usize) -> Self

Creates a new Emergency Brake with the given number of samples and tolerance.

use emergency_brake::EBrake;
let ebrake = EBrake::new(10, 3);